@@ -1,8 +1,8 @@
 """Create elements and references."""
 import os as _os
 import importlib as _il
-from .core import references as _references
-from .core.finite_element import FiniteElement as _FiniteElement
+from . import references as _references
+from .finite_element import FiniteElement as _FiniteElement
 
 _folder = _os.path.dirname(_os.path.realpath(__file__))
 
@@ -144,7 +144,7 @@ def create_element(cell_type, element_type, order, variant="equispaced"):
         serendipity Hdiv, Sdiv, BDMCF, AAF,
         direct serendipity,
         Regge,
-        Nedelec, Nedelec1, N1curl,
+        Nedelec, Nedelec1, N1curl, Ncurl,
         Nedelec2, N2curl,
         Raviart-Thomas, RT, N1div,
         Brezzi-Douglas-Marini, BDM, N2div,
