@@ -4,11 +4,11 @@ This element's definition appears in https://doi.org/10.1007/s10208-011-9087-3
 (Arnold, Awanou, 2011)
 """
 
-from ..core.finite_element import CiarletElement
-from ..core.moments import make_integral_moment_dofs
-from ..core.polynomials import (serendipity_set, polynomial_set,
-                                Hdiv_serendipity, Hcurl_serendipity)
-from ..core.functionals import (
+from ..finite_element import CiarletElement
+from ..moments import make_integral_moment_dofs
+from ..polynomials import (serendipity_set, polynomial_set,
+                           Hdiv_serendipity, Hcurl_serendipity)
+from ..functionals import (
     PointEvaluation, IntegralMoment, TangentIntegralMoment, NormalIntegralMoment)
 from .lagrange import DiscontinuousLagrange, VectorDiscontinuousLagrange
 
